import dotenv from "dotenv";
import express from "express";
import ViteExpress from "vite-express";
import { errorHandler } from "./error_handler.ts";
import MenuRouter from "./menu.ts";
import OrderRouter from "./order.ts";

dotenv.config();
dotenv.config({
  path: ".env.local",
  override: true,
});

const app = express();

app.set("etag", false);
app.use("/api", express.urlencoded({ extended: true }));
app.use("/api", express.json());
app.use("/api", MenuRouter);
app.use("/api", OrderRouter);
app.get("/api/alive", (_, res) => {
  res.send("Alive!");
});
app.use(errorHandler);

ViteExpress.config({
  ignorePaths: /\/api/,
});

const portNum = parseInt(process.env.SERVER_PORT ?? "NaN");
const port = isNaN(portNum) ? 3000 : portNum;

ViteExpress.listen(app, port, () => console.log(`Server is listening on port ${port}...`));
